from typing import List, NoReturn

import grpc
from grpc import Channel, Server

from .workspace_pb2_grpc import add_WorkspaceServiceServicer_to_server, \
    WorkspaceServiceServicer
from .message import CreateRequest, CreateReply, DeleteRequest, DeleteReply, \
    GetByUserRequest, GetByUserReply, Workspace, GetRequest, GetReply, \
    GetManyRequest, GetManyReply

__all__ = ["WorkspaceService", "register_workspace_service"]


class WorkspaceService(WorkspaceServiceServicer):
    def Create(self, request: CreateRequest, context) -> CreateReply:
        workspace = self.create_workspace(
            request.user_id, request.org_id, request.name)
        return CreateReply(workspace=workspace)

    def Delete(self, request: DeleteRequest, context) -> DeleteReply:
        self.delete_workspace(request.id)
        return DeleteReply()

    def ByUser(self, request: GetByUserRequest, context) -> GetByUserReply:
        workspaces = self.get_workspaces_for_user(request.user_id)
        return GetByUserReply(workspaces=workspaces)

    def Get(self, request: GetRequest, context) -> GetReply:
        workspace = self.get_workspace(request.id)
        return GetReply(workspace=workspace)

    def GetMany(self, request: GetManyRequest, context) -> GetManyReply:
        workspaces = self.get_workspaces(request.ids)
        return GetManyReply(workspaces=workspaces)

    def delete_workspace(self, workspace_id: str) -> NoReturn:
        raise NotImplementedError()

    def create_workspace(self, user_id: str, org_id: str,
                         name: str) -> Workspace:
        raise NotImplementedError()

    def get_workspace(self, workspace_id: str) -> Workspace:
        raise NotImplementedError()

    def get_workspaces(self, workspace_ids: List[str]) -> List[Workspace]:
        raise NotImplementedError()

    def get_workspaces_for_user(self, user_id: str) -> List[Workspace]:
        raise NotImplementedError()


def register_workspace_service(service: WorkspaceService, server: Server):
    """
    Register a workspace service with the provided gRPC server.
    """
    add_WorkspaceServiceServicer_to_server(service, server)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import organization_pb2 as organization_dot_organization__pb2


class OrganizationServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/chaosplatform.organization.OrganizationService/Create',
        request_serializer=organization_dot_organization__pb2.CreateRequest.SerializeToString,
        response_deserializer=organization_dot_organization__pb2.CreateReply.FromString,
        )
    self.Get = channel.unary_unary(
        '/chaosplatform.organization.OrganizationService/Get',
        request_serializer=organization_dot_organization__pb2.GetRequest.SerializeToString,
        response_deserializer=organization_dot_organization__pb2.GetReply.FromString,
        )
    self.GetMany = channel.unary_unary(
        '/chaosplatform.organization.OrganizationService/GetMany',
        request_serializer=organization_dot_organization__pb2.GetManyRequest.SerializeToString,
        response_deserializer=organization_dot_organization__pb2.GetManyReply.FromString,
        )
    self.Delete = channel.unary_unary(
        '/chaosplatform.organization.OrganizationService/Delete',
        request_serializer=organization_dot_organization__pb2.DeleteRequest.SerializeToString,
        response_deserializer=organization_dot_organization__pb2.DeleteReply.FromString,
        )
    self.ByUser = channel.unary_unary(
        '/chaosplatform.organization.OrganizationService/ByUser',
        request_serializer=organization_dot_organization__pb2.GetByUserRequest.SerializeToString,
        response_deserializer=organization_dot_organization__pb2.GetByUserReply.FromString,
        )


class OrganizationServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMany(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ByUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_OrganizationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=organization_dot_organization__pb2.CreateRequest.FromString,
          response_serializer=organization_dot_organization__pb2.CreateReply.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=organization_dot_organization__pb2.GetRequest.FromString,
          response_serializer=organization_dot_organization__pb2.GetReply.SerializeToString,
      ),
      'GetMany': grpc.unary_unary_rpc_method_handler(
          servicer.GetMany,
          request_deserializer=organization_dot_organization__pb2.GetManyRequest.FromString,
          response_serializer=organization_dot_organization__pb2.GetManyReply.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=organization_dot_organization__pb2.DeleteRequest.FromString,
          response_serializer=organization_dot_organization__pb2.DeleteReply.SerializeToString,
      ),
      'ByUser': grpc.unary_unary_rpc_method_handler(
          servicer.ByUser,
          request_deserializer=organization_dot_organization__pb2.GetByUserRequest.FromString,
          response_serializer=organization_dot_organization__pb2.GetByUserReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.organization.OrganizationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import scheduler_pb2 as scheduler_dot_scheduler__pb2


class SchedulerServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Schedule = channel.unary_unary(
        '/chaosplatform.schedule.SchedulerService/Schedule',
        request_serializer=scheduler_dot_scheduler__pb2.ScheduleRequest.SerializeToString,
        response_deserializer=scheduler_dot_scheduler__pb2.ScheduleReply.FromString,
        )
    self.Cancel = channel.unary_unary(
        '/chaosplatform.schedule.SchedulerService/Cancel',
        request_serializer=scheduler_dot_scheduler__pb2.CancelRequest.SerializeToString,
        response_deserializer=scheduler_dot_scheduler__pb2.CancelReply.FromString,
        )


class SchedulerServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Schedule(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Cancel(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SchedulerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Schedule': grpc.unary_unary_rpc_method_handler(
          servicer.Schedule,
          request_deserializer=scheduler_dot_scheduler__pb2.ScheduleRequest.FromString,
          response_serializer=scheduler_dot_scheduler__pb2.ScheduleReply.SerializeToString,
      ),
      'Cancel': grpc.unary_unary_rpc_method_handler(
          servicer.Cancel,
          request_deserializer=scheduler_dot_scheduler__pb2.CancelRequest.FromString,
          response_serializer=scheduler_dot_scheduler__pb2.CancelReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.schedule.SchedulerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scheduler/scheduler.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='scheduler/scheduler.proto',
  package='chaosplatform.schedule',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19scheduler/scheduler.proto\x12\x16\x63haosplatform.schedule\"\x9f\x02\n\x08Schedule\x12\x13\n\x0bschedule_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x04 \x01(\t\x12\x15\n\rexperiment_id\x18\x05 \x01(\t\x12\x10\n\x08token_id\x18\x06 \x01(\t\x12\r\n\x05token\x18\x07 \x01(\t\x12\x11\n\tscheduled\x18\x08 \x01(\t\x12\x12\n\nexperiment\x18\t \x01(\t\x12\x10\n\x08interval\x18\n \x01(\x05\x12\x0e\n\x06repeat\x18\x0b \x01(\x05\x12\x0c\n\x04\x63ron\x18\x0c \x01(\t\x12\x10\n\x08settings\x18\r \x01(\t\x12\x15\n\rconfiguration\x18\x0e \x01(\t\x12\x0f\n\x07secrets\x18\x0f \x01(\t\"E\n\x0fScheduleRequest\x12\x32\n\x08schedule\x18\x01 \x01(\x0b\x32 .chaosplatform.schedule.Schedule\"\x1f\n\rScheduleReply\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x1f\n\rCancelRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\r\n\x0b\x43\x61ncelReply2\xc4\x01\n\x10SchedulerService\x12Z\n\x08Schedule\x12\'.chaosplatform.schedule.ScheduleRequest\x1a%.chaosplatform.schedule.ScheduleReply\x12T\n\x06\x43\x61ncel\x12%.chaosplatform.schedule.CancelRequest\x1a#.chaosplatform.schedule.CancelReplyb\x06proto3')
)




_SCHEDULE = _descriptor.Descriptor(
  name='Schedule',
  full_name='chaosplatform.schedule.Schedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule_id', full_name='chaosplatform.schedule.Schedule.schedule_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.schedule.Schedule.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.schedule.Schedule.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.schedule.Schedule.workspace_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='chaosplatform.schedule.Schedule.experiment_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_id', full_name='chaosplatform.schedule.Schedule.token_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='chaosplatform.schedule.Schedule.token', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduled', full_name='chaosplatform.schedule.Schedule.scheduled', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment', full_name='chaosplatform.schedule.Schedule.experiment', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='chaosplatform.schedule.Schedule.interval', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='chaosplatform.schedule.Schedule.repeat', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cron', full_name='chaosplatform.schedule.Schedule.cron', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='chaosplatform.schedule.Schedule.settings', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='chaosplatform.schedule.Schedule.configuration', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='chaosplatform.schedule.Schedule.secrets', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=341,
)


_SCHEDULEREQUEST = _descriptor.Descriptor(
  name='ScheduleRequest',
  full_name='chaosplatform.schedule.ScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='chaosplatform.schedule.ScheduleRequest.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=412,
)


_SCHEDULEREPLY = _descriptor.Descriptor(
  name='ScheduleReply',
  full_name='chaosplatform.schedule.ScheduleReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='chaosplatform.schedule.ScheduleReply.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=445,
)


_CANCELREQUEST = _descriptor.Descriptor(
  name='CancelRequest',
  full_name='chaosplatform.schedule.CancelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='chaosplatform.schedule.CancelRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=478,
)


_CANCELREPLY = _descriptor.Descriptor(
  name='CancelReply',
  full_name='chaosplatform.schedule.CancelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=493,
)

_SCHEDULEREQUEST.fields_by_name['schedule'].message_type = _SCHEDULE
DESCRIPTOR.message_types_by_name['Schedule'] = _SCHEDULE
DESCRIPTOR.message_types_by_name['ScheduleRequest'] = _SCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['ScheduleReply'] = _SCHEDULEREPLY
DESCRIPTOR.message_types_by_name['CancelRequest'] = _CANCELREQUEST
DESCRIPTOR.message_types_by_name['CancelReply'] = _CANCELREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULE,
  __module__ = 'scheduler.scheduler_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.schedule.Schedule)
  ))
_sym_db.RegisterMessage(Schedule)

ScheduleRequest = _reflection.GeneratedProtocolMessageType('ScheduleRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEREQUEST,
  __module__ = 'scheduler.scheduler_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.schedule.ScheduleRequest)
  ))
_sym_db.RegisterMessage(ScheduleRequest)

ScheduleReply = _reflection.GeneratedProtocolMessageType('ScheduleReply', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEREPLY,
  __module__ = 'scheduler.scheduler_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.schedule.ScheduleReply)
  ))
_sym_db.RegisterMessage(ScheduleReply)

CancelRequest = _reflection.GeneratedProtocolMessageType('CancelRequest', (_message.Message,), dict(
  DESCRIPTOR = _CANCELREQUEST,
  __module__ = 'scheduler.scheduler_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.schedule.CancelRequest)
  ))
_sym_db.RegisterMessage(CancelRequest)

CancelReply = _reflection.GeneratedProtocolMessageType('CancelReply', (_message.Message,), dict(
  DESCRIPTOR = _CANCELREPLY,
  __module__ = 'scheduler.scheduler_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.schedule.CancelReply)
  ))
_sym_db.RegisterMessage(CancelReply)



_SCHEDULERSERVICE = _descriptor.ServiceDescriptor(
  name='SchedulerService',
  full_name='chaosplatform.schedule.SchedulerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=496,
  serialized_end=692,
  methods=[
  _descriptor.MethodDescriptor(
    name='Schedule',
    full_name='chaosplatform.schedule.SchedulerService.Schedule',
    index=0,
    containing_service=None,
    input_type=_SCHEDULEREQUEST,
    output_type=_SCHEDULEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Cancel',
    full_name='chaosplatform.schedule.SchedulerService.Cancel',
    index=1,
    containing_service=None,
    input_type=_CANCELREQUEST,
    output_type=_CANCELREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCHEDULERSERVICE)

DESCRIPTOR.services_by_name['SchedulerService'] = _SCHEDULERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import auth_pb2 as auth_dot_auth__pb2


class AuthServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/chaosplatform.auth.AuthService/Create',
        request_serializer=auth_dot_auth__pb2.CreateRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.CreateReply.FromString,
        )
    self.Delete = channel.unary_unary(
        '/chaosplatform.auth.AuthService/Delete',
        request_serializer=auth_dot_auth__pb2.DeleteRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.DeleteReply.FromString,
        )
    self.Revoke = channel.unary_unary(
        '/chaosplatform.auth.AuthService/Revoke',
        request_serializer=auth_dot_auth__pb2.RevokeRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.RevokeReply.FromString,
        )
    self.Get = channel.unary_unary(
        '/chaosplatform.auth.AuthService/Get',
        request_serializer=auth_dot_auth__pb2.GetRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.GetReply.FromString,
        )
    self.GetByName = channel.unary_unary(
        '/chaosplatform.auth.AuthService/GetByName',
        request_serializer=auth_dot_auth__pb2.GetByNameRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.GetByNameReply.FromString,
        )
    self.GetByUser = channel.unary_unary(
        '/chaosplatform.auth.AuthService/GetByUser',
        request_serializer=auth_dot_auth__pb2.GetByUserRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.GetByUserReply.FromString,
        )
    self.GetByOrg = channel.unary_unary(
        '/chaosplatform.auth.AuthService/GetByOrg',
        request_serializer=auth_dot_auth__pb2.GetByOrgRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.GetByOrgReply.FromString,
        )
    self.GetByWorkspace = channel.unary_unary(
        '/chaosplatform.auth.AuthService/GetByWorkspace',
        request_serializer=auth_dot_auth__pb2.GetByWorkspaceRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.GetByWorkspaceReply.FromString,
        )
    self.GetByJti = channel.unary_unary(
        '/chaosplatform.auth.AuthService/GetByJti',
        request_serializer=auth_dot_auth__pb2.GetByJtiRequest.SerializeToString,
        response_deserializer=auth_dot_auth__pb2.GetByJtiReply.FromString,
        )


class AuthServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Revoke(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByOrg(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByWorkspace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByJti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=auth_dot_auth__pb2.CreateRequest.FromString,
          response_serializer=auth_dot_auth__pb2.CreateReply.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=auth_dot_auth__pb2.DeleteRequest.FromString,
          response_serializer=auth_dot_auth__pb2.DeleteReply.SerializeToString,
      ),
      'Revoke': grpc.unary_unary_rpc_method_handler(
          servicer.Revoke,
          request_deserializer=auth_dot_auth__pb2.RevokeRequest.FromString,
          response_serializer=auth_dot_auth__pb2.RevokeReply.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=auth_dot_auth__pb2.GetRequest.FromString,
          response_serializer=auth_dot_auth__pb2.GetReply.SerializeToString,
      ),
      'GetByName': grpc.unary_unary_rpc_method_handler(
          servicer.GetByName,
          request_deserializer=auth_dot_auth__pb2.GetByNameRequest.FromString,
          response_serializer=auth_dot_auth__pb2.GetByNameReply.SerializeToString,
      ),
      'GetByUser': grpc.unary_unary_rpc_method_handler(
          servicer.GetByUser,
          request_deserializer=auth_dot_auth__pb2.GetByUserRequest.FromString,
          response_serializer=auth_dot_auth__pb2.GetByUserReply.SerializeToString,
      ),
      'GetByOrg': grpc.unary_unary_rpc_method_handler(
          servicer.GetByOrg,
          request_deserializer=auth_dot_auth__pb2.GetByOrgRequest.FromString,
          response_serializer=auth_dot_auth__pb2.GetByOrgReply.SerializeToString,
      ),
      'GetByWorkspace': grpc.unary_unary_rpc_method_handler(
          servicer.GetByWorkspace,
          request_deserializer=auth_dot_auth__pb2.GetByWorkspaceRequest.FromString,
          response_serializer=auth_dot_auth__pb2.GetByWorkspaceReply.SerializeToString,
      ),
      'GetByJti': grpc.unary_unary_rpc_method_handler(
          servicer.GetByJti,
          request_deserializer=auth_dot_auth__pb2.GetByJtiRequest.FromString,
          response_serializer=auth_dot_auth__pb2.GetByJtiReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.auth.AuthService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: organization/organization.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='organization/organization.proto',
  package='chaosplatform.organization',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1forganization/organization.proto\x12\x1a\x63haosplatform.organization\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"5\n\x06Member\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\x08\"\xda\x01\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12.\n\ncreated_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rworkspace_ids\x18\x05 \x03(\t\x12\x33\n\x07members\x18\x06 \x03(\x0b\x32\".chaosplatform.organization.Member\x12&\n\x08settings\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\".\n\rCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"M\n\x0b\x43reateReply\x12>\n\x0corganization\x18\x02 \x01(\x0b\x32(.chaosplatform.organization.Organization\"\x1b\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\r\n\x0b\x44\x65leteReply\"\x18\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"J\n\x08GetReply\x12>\n\x0corganization\x18\x01 \x01(\x0b\x32(.chaosplatform.organization.Organization\"\x1d\n\x0eGetManyRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"O\n\x0cGetManyReply\x12?\n\rorganizations\x18\x01 \x03(\x0b\x32(.chaosplatform.organization.Organization\"#\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"Q\n\x0eGetByUserReply\x12?\n\rorganizations\x18\x01 \x03(\x0b\x32(.chaosplatform.organization.Organization2\xeb\x03\n\x13OrganizationService\x12\\\n\x06\x43reate\x12).chaosplatform.organization.CreateRequest\x1a\'.chaosplatform.organization.CreateReply\x12S\n\x03Get\x12&.chaosplatform.organization.GetRequest\x1a$.chaosplatform.organization.GetReply\x12_\n\x07GetMany\x12*.chaosplatform.organization.GetManyRequest\x1a(.chaosplatform.organization.GetManyReply\x12\\\n\x06\x44\x65lete\x12).chaosplatform.organization.DeleteRequest\x1a\'.chaosplatform.organization.DeleteReply\x12\x62\n\x06\x42yUser\x12,.chaosplatform.organization.GetByUserRequest\x1a*.chaosplatform.organization.GetByUserReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='chaosplatform.organization.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.organization.Member.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.organization.Member.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='chaosplatform.organization.Member.owner', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=176,
)


_ORGANIZATION = _descriptor.Descriptor(
  name='Organization',
  full_name='chaosplatform.organization.Organization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.organization.Organization.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.organization.Organization.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='chaosplatform.organization.Organization.kind', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_on', full_name='chaosplatform.organization.Organization.created_on', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_ids', full_name='chaosplatform.organization.Organization.workspace_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='members', full_name='chaosplatform.organization.Organization.members', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='chaosplatform.organization.Organization.settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=397,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.organization.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.organization.CreateRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.organization.CreateRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=445,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.organization.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization', full_name='chaosplatform.organization.CreateReply.organization', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=524,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.organization.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.organization.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=553,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.organization.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=568,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.organization.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.organization.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=594,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.organization.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization', full_name='chaosplatform.organization.GetReply.organization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=670,
)


_GETMANYREQUEST = _descriptor.Descriptor(
  name='GetManyRequest',
  full_name='chaosplatform.organization.GetManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='chaosplatform.organization.GetManyRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=701,
)


_GETMANYREPLY = _descriptor.Descriptor(
  name='GetManyReply',
  full_name='chaosplatform.organization.GetManyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organizations', full_name='chaosplatform.organization.GetManyReply.organizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=782,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.organization.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.organization.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=819,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.organization.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='organizations', full_name='chaosplatform.organization.GetByUserReply.organizations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=902,
)

_ORGANIZATION.fields_by_name['created_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORGANIZATION.fields_by_name['members'].message_type = _MEMBER
_ORGANIZATION.fields_by_name['settings'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CREATEREPLY.fields_by_name['organization'].message_type = _ORGANIZATION
_GETREPLY.fields_by_name['organization'].message_type = _ORGANIZATION
_GETMANYREPLY.fields_by_name['organizations'].message_type = _ORGANIZATION
_GETBYUSERREPLY.fields_by_name['organizations'].message_type = _ORGANIZATION
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['Organization'] = _ORGANIZATION
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetManyRequest'] = _GETMANYREQUEST
DESCRIPTOR.message_types_by_name['GetManyReply'] = _GETMANYREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.Member)
  ))
_sym_db.RegisterMessage(Member)

Organization = _reflection.GeneratedProtocolMessageType('Organization', (_message.Message,), dict(
  DESCRIPTOR = _ORGANIZATION,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.Organization)
  ))
_sym_db.RegisterMessage(Organization)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetManyRequest = _reflection.GeneratedProtocolMessageType('GetManyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREQUEST,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.GetManyRequest)
  ))
_sym_db.RegisterMessage(GetManyRequest)

GetManyReply = _reflection.GeneratedProtocolMessageType('GetManyReply', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREPLY,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.GetManyReply)
  ))
_sym_db.RegisterMessage(GetManyReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'organization.organization_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.organization.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)



_ORGANIZATIONSERVICE = _descriptor.ServiceDescriptor(
  name='OrganizationService',
  full_name='chaosplatform.organization.OrganizationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=905,
  serialized_end=1396,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.organization.OrganizationService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.organization.OrganizationService.Get',
    index=1,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMany',
    full_name='chaosplatform.organization.OrganizationService.GetMany',
    index=2,
    containing_service=None,
    input_type=_GETMANYREQUEST,
    output_type=_GETMANYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.organization.OrganizationService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ByUser',
    full_name='chaosplatform.organization.OrganizationService.ByUser',
    index=4,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ORGANIZATIONSERVICE)

DESCRIPTOR.services_by_name['OrganizationService'] = _ORGANIZATIONSERVICE

# @@protoc_insertion_point(module_scope)



from typing import List

from grpc import Server

from .scheduling_pb2_grpc import add_SchedulingServiceServicer_to_server, \
    SchedulingServiceServicer
from .message import GetRequest, GetReply, GetManyRequest, GetManyReply, \
    Schedule, GetByUserRequest, GetByUserReply, GetByExperimentRequest, \
    GetByOrgRequest, GetByOrgReply, GetByWorkspaceRequest, \
    GetByWorkspaceReply, GetByExperimentReply

__all__ = ["SchedulingService", "register_scheduling_service"]


class SchedulingService(SchedulingServiceServicer):
    def Get(self, request: GetRequest, context) -> GetReply:
        schedule = self.get_scheduling(request.id, request.with_payload)
        return GetReply(schedule=schedule)

    def GetMany(self, request: GetManyRequest, context) -> GetManyReply:
        schedules = self.get_schedulings(request.ids, request.with_payload)
        return GetManyReply(schedules=schedules)

    def GetByUser(self, request: GetByUserRequest, context) -> GetByUserReply:
        schedules = self.get_by_user(request.user_id, request.with_payload)
        return GetByUserReply(schedules=schedules)

    def GetByOrg(self, request: GetByOrgRequest, context) -> GetByOrgReply:
        schedules = self.get_by_org(request.org_id, request.with_payload)
        return GetByOrgReply(schedules=schedules)

    def GetByWorkspace(self, request: GetByWorkspaceRequest,
                       context) -> GetByWorkspaceReply:
        schedules = self.get_by_workspace(
            request.workspace_id, request.with_payload)
        return GetByWorkspaceReply(schedules=schedules)

    def GetByExperiment(self, request: GetByExperimentRequest,
                        context) -> GetByExperimentReply:
        schedules = self.get_by_experiment(
            request.experiment_id, request.with_payload)
        return GetByExperimentReply(schedules=schedules)

    def get_scheduling(self, scheduling_id: str,
                       with_payload: bool = False) -> Schedule:
        raise NotImplementedError()

    def get_schedulings(self, scheduling_ids: List[str],
                        with_payload: bool = False) -> List[Schedule]:
        raise NotImplementedError()

    def get_by_user(self, user_id: str,
                    with_payload: bool = False) -> List[Schedule]:
        raise NotImplementedError()

    def get_by_org(self, org_id: str,
                   with_payload: bool = False) -> List[Schedule]:
        raise NotImplementedError()

    def get_by_workspace(self, workspace_id: str,
                         with_payload: bool = False) -> List[Schedule]:
        raise NotImplementedError()

    def get_by_experiment(self, experiment_id: str,
                          with_payload: bool = False) -> List[Schedule]:
        raise NotImplementedError()


def register_scheduling_service(service: SchedulingService, server: Server):
    """
    Register a scheduling service with the provided gRPC server.
    """
    add_SchedulingServiceServicer_to_server(service, server)



from typing import List, NoReturn

import grpc
from grpc import Channel, Server

from .user_pb2_grpc import add_UserServiceServicer_to_server, \
    UserServiceServicer
from .message import CreateRequest, CreateReply, DeleteRequest, DeleteReply, \
    User

__all__ = ["UserService", "register_user_service"]


class UserService(UserServiceServicer):
    def Create(self, request: CreateRequest, context) -> CreateReply:
        user = self.create_user(request.username, request.user_id)
        return CreateReply(user=user)

    def Delete(self, request: DeleteRequest, context) -> DeleteReply:
        self.delete_user(request.id)
        return DeleteReply()

    def create_user(self, user_id: str, name: str) -> User:
        raise NotImplementedError()

    def delete_user(self, user_id: str) -> NoReturn:
        raise NotImplementedError()


def register_user_service(service: UserService, server: Server):
    """
    Register a user service with the provided gRPC server.
    """
    add_UserServiceServicer_to_server(service, server)



from typing import List, NoReturn

import grpc
from grpc import Channel

from .user_pb2_grpc import UserServiceStub
from .message import CreateRequest, DeleteRequest, User

__all__ = ["create_user", "delete_user"]


def create_user(channel: Channel, username: str) -> User:
    """
    Create a user.
    """
    stub = UserServiceStub(channel)
    response = stub.Create(CreateRequest(username=username))
    return response.user


def delete_user(channel: Channel, user_id: str) -> NoReturn:
    """
    Delete a user.
    """
    stub = UserServiceStub(channel)
    stub.Delete(DeleteRequest(id=user_id))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import scheduling_pb2 as scheduling_dot_scheduling__pb2


class SchedulingServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Get = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/Get',
        request_serializer=scheduling_dot_scheduling__pb2.GetRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetReply.FromString,
        )
    self.GetMany = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetMany',
        request_serializer=scheduling_dot_scheduling__pb2.GetManyRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetManyReply.FromString,
        )
    self.GetByUser = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByUser',
        request_serializer=scheduling_dot_scheduling__pb2.GetByUserRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByUserReply.FromString,
        )
    self.GetByOrg = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByOrg',
        request_serializer=scheduling_dot_scheduling__pb2.GetByOrgRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByOrgReply.FromString,
        )
    self.GetByWorkspace = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByWorkspace',
        request_serializer=scheduling_dot_scheduling__pb2.GetByWorkspaceRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByWorkspaceReply.FromString,
        )
    self.GetByExperiment = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByExperiment',
        request_serializer=scheduling_dot_scheduling__pb2.GetByExperimentRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByExperimentReply.FromString,
        )
    self.GetByAccessToken = channel.unary_unary(
        '/chaosplatform.scheduling.SchedulingService/GetByAccessToken',
        request_serializer=scheduling_dot_scheduling__pb2.GetByAccessTokenRequest.SerializeToString,
        response_deserializer=scheduling_dot_scheduling__pb2.GetByAccessTokenReply.FromString,
        )


class SchedulingServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMany(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByOrg(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByWorkspace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByExperiment(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetByAccessToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SchedulingServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=scheduling_dot_scheduling__pb2.GetRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetReply.SerializeToString,
      ),
      'GetMany': grpc.unary_unary_rpc_method_handler(
          servicer.GetMany,
          request_deserializer=scheduling_dot_scheduling__pb2.GetManyRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetManyReply.SerializeToString,
      ),
      'GetByUser': grpc.unary_unary_rpc_method_handler(
          servicer.GetByUser,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByUserRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByUserReply.SerializeToString,
      ),
      'GetByOrg': grpc.unary_unary_rpc_method_handler(
          servicer.GetByOrg,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByOrgRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByOrgReply.SerializeToString,
      ),
      'GetByWorkspace': grpc.unary_unary_rpc_method_handler(
          servicer.GetByWorkspace,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByWorkspaceRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByWorkspaceReply.SerializeToString,
      ),
      'GetByExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.GetByExperiment,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByExperimentRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByExperimentReply.SerializeToString,
      ),
      'GetByAccessToken': grpc.unary_unary_rpc_method_handler(
          servicer.GetByAccessToken,
          request_deserializer=scheduling_dot_scheduling__pb2.GetByAccessTokenRequest.FromString,
          response_serializer=scheduling_dot_scheduling__pb2.GetByAccessTokenReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'chaosplatform.scheduling.SchedulingService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace/workspace.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='workspace/workspace.proto',
  package='chaosplatform.workspace',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19workspace/workspace.proto\x12\x17\x63haosplatform.workspace\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x0c\x43ollaborator\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\x08\"\xeb\x01\n\tWorkspace\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x10\n\x08org_name\x18\x04 \x01(\t\x12\x0c\n\x04kind\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\rcollaborators\x18\x08 \x03(\x0b\x32%.chaosplatform.workspace.Collaborator\x12&\n\x08settings\x18\t \x01(\x0b\x32\x14.google.protobuf.Any\">\n\rCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\"D\n\x0b\x43reateReply\x12\x35\n\tworkspace\x18\x02 \x01(\x0b\x32\".chaosplatform.workspace.Workspace\"\x1b\n\rDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\r\n\x0b\x44\x65leteReply\"\x18\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"A\n\x08GetReply\x12\x35\n\tworkspace\x18\x01 \x01(\x0b\x32\".chaosplatform.workspace.Workspace\"\x1d\n\x0eGetManyRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"F\n\x0cGetManyReply\x12\x36\n\nworkspaces\x18\x01 \x03(\x0b\x32\".chaosplatform.workspace.Workspace\"#\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"H\n\x0eGetByUserReply\x12\x36\n\nworkspaces\x18\x01 \x03(\x0b\x32\".chaosplatform.workspace.Workspace2\xca\x03\n\x10WorkspaceService\x12V\n\x06\x43reate\x12&.chaosplatform.workspace.CreateRequest\x1a$.chaosplatform.workspace.CreateReply\x12M\n\x03Get\x12#.chaosplatform.workspace.GetRequest\x1a!.chaosplatform.workspace.GetReply\x12Y\n\x07GetMany\x12\'.chaosplatform.workspace.GetManyRequest\x1a%.chaosplatform.workspace.GetManyReply\x12V\n\x06\x44\x65lete\x12&.chaosplatform.workspace.DeleteRequest\x1a$.chaosplatform.workspace.DeleteReply\x12\\\n\x06\x42yUser\x12).chaosplatform.workspace.GetByUserRequest\x1a\'.chaosplatform.workspace.GetByUserReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_COLLABORATOR = _descriptor.Descriptor(
  name='Collaborator',
  full_name='chaosplatform.workspace.Collaborator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.Collaborator.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='chaosplatform.workspace.Collaborator.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='chaosplatform.workspace.Collaborator.owner', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=173,
)


_WORKSPACE = _descriptor.Descriptor(
  name='Workspace',
  full_name='chaosplatform.workspace.Workspace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.Workspace.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.workspace.Workspace.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.workspace.Workspace.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_name', full_name='chaosplatform.workspace.Workspace.org_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='chaosplatform.workspace.Workspace.kind', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_on', full_name='chaosplatform.workspace.Workspace.created_on', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaborators', full_name='chaosplatform.workspace.Workspace.collaborators', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='chaosplatform.workspace.Workspace.settings', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=411,
)


_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='chaosplatform.workspace.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='chaosplatform.workspace.CreateRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.workspace.CreateRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.workspace.CreateRequest.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=475,
)


_CREATEREPLY = _descriptor.Descriptor(
  name='CreateReply',
  full_name='chaosplatform.workspace.CreateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='chaosplatform.workspace.CreateReply.workspace', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=545,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='chaosplatform.workspace.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.DeleteRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=574,
)


_DELETEREPLY = _descriptor.Descriptor(
  name='DeleteReply',
  full_name='chaosplatform.workspace.DeleteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=589,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.workspace.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.workspace.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=615,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.workspace.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='chaosplatform.workspace.GetReply.workspace', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=682,
)


_GETMANYREQUEST = _descriptor.Descriptor(
  name='GetManyRequest',
  full_name='chaosplatform.workspace.GetManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='chaosplatform.workspace.GetManyRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=713,
)


_GETMANYREPLY = _descriptor.Descriptor(
  name='GetManyReply',
  full_name='chaosplatform.workspace.GetManyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaces', full_name='chaosplatform.workspace.GetManyReply.workspaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=785,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.workspace.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.workspace.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=822,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.workspace.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaces', full_name='chaosplatform.workspace.GetByUserReply.workspaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=896,
)

_WORKSPACE.fields_by_name['created_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKSPACE.fields_by_name['collaborators'].message_type = _COLLABORATOR
_WORKSPACE.fields_by_name['settings'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CREATEREPLY.fields_by_name['workspace'].message_type = _WORKSPACE
_GETREPLY.fields_by_name['workspace'].message_type = _WORKSPACE
_GETMANYREPLY.fields_by_name['workspaces'].message_type = _WORKSPACE
_GETBYUSERREPLY.fields_by_name['workspaces'].message_type = _WORKSPACE
DESCRIPTOR.message_types_by_name['Collaborator'] = _COLLABORATOR
DESCRIPTOR.message_types_by_name['Workspace'] = _WORKSPACE
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['CreateReply'] = _CREATEREPLY
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteReply'] = _DELETEREPLY
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetManyRequest'] = _GETMANYREQUEST
DESCRIPTOR.message_types_by_name['GetManyReply'] = _GETMANYREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Collaborator = _reflection.GeneratedProtocolMessageType('Collaborator', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATOR,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.Collaborator)
  ))
_sym_db.RegisterMessage(Collaborator)

Workspace = _reflection.GeneratedProtocolMessageType('Workspace', (_message.Message,), dict(
  DESCRIPTOR = _WORKSPACE,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.Workspace)
  ))
_sym_db.RegisterMessage(Workspace)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

CreateReply = _reflection.GeneratedProtocolMessageType('CreateReply', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.CreateReply)
  ))
_sym_db.RegisterMessage(CreateReply)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteReply = _reflection.GeneratedProtocolMessageType('DeleteReply', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.DeleteReply)
  ))
_sym_db.RegisterMessage(DeleteReply)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetManyRequest = _reflection.GeneratedProtocolMessageType('GetManyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetManyRequest)
  ))
_sym_db.RegisterMessage(GetManyRequest)

GetManyReply = _reflection.GeneratedProtocolMessageType('GetManyReply', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetManyReply)
  ))
_sym_db.RegisterMessage(GetManyReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'workspace.workspace_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.workspace.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)



_WORKSPACESERVICE = _descriptor.ServiceDescriptor(
  name='WorkspaceService',
  full_name='chaosplatform.workspace.WorkspaceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=899,
  serialized_end=1357,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='chaosplatform.workspace.WorkspaceService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=_CREATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.workspace.WorkspaceService.Get',
    index=1,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMany',
    full_name='chaosplatform.workspace.WorkspaceService.GetMany',
    index=2,
    containing_service=None,
    input_type=_GETMANYREQUEST,
    output_type=_GETMANYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='chaosplatform.workspace.WorkspaceService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ByUser',
    full_name='chaosplatform.workspace.WorkspaceService.ByUser',
    index=4,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKSPACESERVICE)

DESCRIPTOR.services_by_name['WorkspaceService'] = _WORKSPACESERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: experiment/experiment.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from chaosplt_grpc.execution import execution_pb2 as execution_dot_execution__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='experiment/experiment.proto',
  package='chaosplatform.experiment',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1b\x65xperiment/experiment.proto\x12\x18\x63haosplatform.experiment\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x65xecution/execution.proto\"\xaa\x02\n\nExperiment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06org_id\x18\x03 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\nexecutions\x18\n \x03(\x0b\x32\".chaosplatform.execution.Execution\x12\x0f\n\x07payload\x18\x0b \x01(\t\".\n\nGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"D\n\x08GetReply\x12\x38\n\nexperiment\x18\x01 \x01(\x0b\x32$.chaosplatform.experiment.Experiment\"3\n\x0eGetManyRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"I\n\x0cGetManyReply\x12\x39\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32$.chaosplatform.experiment.Experiment\"9\n\x10GetByUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"K\n\x0eGetByUserReply\x12\x39\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32$.chaosplatform.experiment.Experiment\"7\n\x0fGetByOrgRequest\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"J\n\rGetByOrgReply\x12\x39\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32$.chaosplatform.experiment.Experiment\"C\n\x15GetByWorkspaceRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x14\n\x0cwith_payload\x18\x02 \x01(\x08\"P\n\x13GetByWorkspaceReply\x12\x39\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32$.chaosplatform.experiment.Experiment2\xf6\x03\n\x11\x45xperimentService\x12O\n\x03Get\x12$.chaosplatform.experiment.GetRequest\x1a\".chaosplatform.experiment.GetReply\x12[\n\x07GetMany\x12(.chaosplatform.experiment.GetManyRequest\x1a&.chaosplatform.experiment.GetManyReply\x12\x61\n\tGetByUser\x12*.chaosplatform.experiment.GetByUserRequest\x1a(.chaosplatform.experiment.GetByUserReply\x12^\n\x08GetByOrg\x12).chaosplatform.experiment.GetByOrgRequest\x1a\'.chaosplatform.experiment.GetByOrgReply\x12p\n\x0eGetByWorkspace\x12/.chaosplatform.experiment.GetByWorkspaceRequest\x1a-.chaosplatform.experiment.GetByWorkspaceReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,execution_dot_execution__pb2.DESCRIPTOR,])




_EXPERIMENT = _descriptor.Descriptor(
  name='Experiment',
  full_name='chaosplatform.experiment.Experiment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.experiment.Experiment.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.experiment.Experiment.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.experiment.Experiment.org_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.experiment.Experiment.workspace_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='chaosplatform.experiment.Experiment.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='chaosplatform.experiment.Experiment.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='chaosplatform.experiment.Experiment.tags', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_on', full_name='chaosplatform.experiment.Experiment.created_on', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_on', full_name='chaosplatform.experiment.Experiment.updated_on', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executions', full_name='chaosplatform.experiment.Experiment.executions', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='chaosplatform.experiment.Experiment.payload', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=416,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='chaosplatform.experiment.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='chaosplatform.experiment.GetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.experiment.GetRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=464,
)


_GETREPLY = _descriptor.Descriptor(
  name='GetReply',
  full_name='chaosplatform.experiment.GetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment', full_name='chaosplatform.experiment.GetReply.experiment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=534,
)


_GETMANYREQUEST = _descriptor.Descriptor(
  name='GetManyRequest',
  full_name='chaosplatform.experiment.GetManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='chaosplatform.experiment.GetManyRequest.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.experiment.GetManyRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=587,
)


_GETMANYREPLY = _descriptor.Descriptor(
  name='GetManyReply',
  full_name='chaosplatform.experiment.GetManyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiments', full_name='chaosplatform.experiment.GetManyReply.experiments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=662,
)


_GETBYUSERREQUEST = _descriptor.Descriptor(
  name='GetByUserRequest',
  full_name='chaosplatform.experiment.GetByUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='chaosplatform.experiment.GetByUserRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.experiment.GetByUserRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=721,
)


_GETBYUSERREPLY = _descriptor.Descriptor(
  name='GetByUserReply',
  full_name='chaosplatform.experiment.GetByUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiments', full_name='chaosplatform.experiment.GetByUserReply.experiments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=798,
)


_GETBYORGREQUEST = _descriptor.Descriptor(
  name='GetByOrgRequest',
  full_name='chaosplatform.experiment.GetByOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='chaosplatform.experiment.GetByOrgRequest.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.experiment.GetByOrgRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=855,
)


_GETBYORGREPLY = _descriptor.Descriptor(
  name='GetByOrgReply',
  full_name='chaosplatform.experiment.GetByOrgReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiments', full_name='chaosplatform.experiment.GetByOrgReply.experiments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=931,
)


_GETBYWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetByWorkspaceRequest',
  full_name='chaosplatform.experiment.GetByWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='chaosplatform.experiment.GetByWorkspaceRequest.workspace_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_payload', full_name='chaosplatform.experiment.GetByWorkspaceRequest.with_payload', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=1000,
)


_GETBYWORKSPACEREPLY = _descriptor.Descriptor(
  name='GetByWorkspaceReply',
  full_name='chaosplatform.experiment.GetByWorkspaceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiments', full_name='chaosplatform.experiment.GetByWorkspaceReply.experiments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1082,
)

_EXPERIMENT.fields_by_name['created_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENT.fields_by_name['updated_on'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENT.fields_by_name['executions'].message_type = execution_dot_execution__pb2._EXECUTION
_GETREPLY.fields_by_name['experiment'].message_type = _EXPERIMENT
_GETMANYREPLY.fields_by_name['experiments'].message_type = _EXPERIMENT
_GETBYUSERREPLY.fields_by_name['experiments'].message_type = _EXPERIMENT
_GETBYORGREPLY.fields_by_name['experiments'].message_type = _EXPERIMENT
_GETBYWORKSPACEREPLY.fields_by_name['experiments'].message_type = _EXPERIMENT
DESCRIPTOR.message_types_by_name['Experiment'] = _EXPERIMENT
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetReply'] = _GETREPLY
DESCRIPTOR.message_types_by_name['GetManyRequest'] = _GETMANYREQUEST
DESCRIPTOR.message_types_by_name['GetManyReply'] = _GETMANYREPLY
DESCRIPTOR.message_types_by_name['GetByUserRequest'] = _GETBYUSERREQUEST
DESCRIPTOR.message_types_by_name['GetByUserReply'] = _GETBYUSERREPLY
DESCRIPTOR.message_types_by_name['GetByOrgRequest'] = _GETBYORGREQUEST
DESCRIPTOR.message_types_by_name['GetByOrgReply'] = _GETBYORGREPLY
DESCRIPTOR.message_types_by_name['GetByWorkspaceRequest'] = _GETBYWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetByWorkspaceReply'] = _GETBYWORKSPACEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Experiment = _reflection.GeneratedProtocolMessageType('Experiment', (_message.Message,), dict(
  DESCRIPTOR = _EXPERIMENT,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.Experiment)
  ))
_sym_db.RegisterMessage(Experiment)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetReply = _reflection.GeneratedProtocolMessageType('GetReply', (_message.Message,), dict(
  DESCRIPTOR = _GETREPLY,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetReply)
  ))
_sym_db.RegisterMessage(GetReply)

GetManyRequest = _reflection.GeneratedProtocolMessageType('GetManyRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREQUEST,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetManyRequest)
  ))
_sym_db.RegisterMessage(GetManyRequest)

GetManyReply = _reflection.GeneratedProtocolMessageType('GetManyReply', (_message.Message,), dict(
  DESCRIPTOR = _GETMANYREPLY,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetManyReply)
  ))
_sym_db.RegisterMessage(GetManyReply)

GetByUserRequest = _reflection.GeneratedProtocolMessageType('GetByUserRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREQUEST,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetByUserRequest)
  ))
_sym_db.RegisterMessage(GetByUserRequest)

GetByUserReply = _reflection.GeneratedProtocolMessageType('GetByUserReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYUSERREPLY,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetByUserReply)
  ))
_sym_db.RegisterMessage(GetByUserReply)

GetByOrgRequest = _reflection.GeneratedProtocolMessageType('GetByOrgRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREQUEST,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetByOrgRequest)
  ))
_sym_db.RegisterMessage(GetByOrgRequest)

GetByOrgReply = _reflection.GeneratedProtocolMessageType('GetByOrgReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYORGREPLY,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetByOrgReply)
  ))
_sym_db.RegisterMessage(GetByOrgReply)

GetByWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetByWorkspaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREQUEST,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetByWorkspaceRequest)
  ))
_sym_db.RegisterMessage(GetByWorkspaceRequest)

GetByWorkspaceReply = _reflection.GeneratedProtocolMessageType('GetByWorkspaceReply', (_message.Message,), dict(
  DESCRIPTOR = _GETBYWORKSPACEREPLY,
  __module__ = 'experiment.experiment_pb2'
  # @@protoc_insertion_point(class_scope:chaosplatform.experiment.GetByWorkspaceReply)
  ))
_sym_db.RegisterMessage(GetByWorkspaceReply)



_EXPERIMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ExperimentService',
  full_name='chaosplatform.experiment.ExperimentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1085,
  serialized_end=1587,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='chaosplatform.experiment.ExperimentService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMany',
    full_name='chaosplatform.experiment.ExperimentService.GetMany',
    index=1,
    containing_service=None,
    input_type=_GETMANYREQUEST,
    output_type=_GETMANYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByUser',
    full_name='chaosplatform.experiment.ExperimentService.GetByUser',
    index=2,
    containing_service=None,
    input_type=_GETBYUSERREQUEST,
    output_type=_GETBYUSERREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByOrg',
    full_name='chaosplatform.experiment.ExperimentService.GetByOrg',
    index=3,
    containing_service=None,
    input_type=_GETBYORGREQUEST,
    output_type=_GETBYORGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetByWorkspace',
    full_name='chaosplatform.experiment.ExperimentService.GetByWorkspace',
    index=4,
    containing_service=None,
    input_type=_GETBYWORKSPACEREQUEST,
    output_type=_GETBYWORKSPACEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXPERIMENTSERVICE)

DESCRIPTOR.services_by_name['ExperimentService'] = _EXPERIMENTSERVICE

# @@protoc_insertion_point(module_scope)



from typing import NoReturn

import grpc
from grpc import Channel, Server

from .registration_pb2_grpc import RegistrationServiceServicer, \
    add_RegistrationServiceServicer_to_server
from .message import Registration, CreateRequest, CreateReply, DeleteRequest, \
    DeleteReply, GetByIdRequest, GetByIdReply

__all__ = ["RegistrationService", "register_registration_service"]


class RegistrationService(RegistrationServiceServicer):
    def Create(self, request: CreateRequest, context) -> CreateReply:
        registration = self.create_registration(
            request.username, request.name, request.email)
        return CreateReply(registration=registration)

    def Delete(self, request: DeleteRequest, context) -> DeleteReply:
        self.delete_registration(request.id)
        return DeleteReply()

    def GetById(self, request: GetByIdRequest, context) -> GetByIdReply:
        registration = self.get_by_id(request.id)
        return GetByIdReply(registration=registration)

    def create_registration(self, user_id: str, username: str, name: str,
                            email: str) -> Registration:
        raise NotImplementedError()

    def delete_registration(self, registration_id: str) -> NoReturn:
        raise NotImplementedError()

    def get_by_id(self, registration_id: str) -> Registration:
        raise NotImplementedError()


def register_registration_service(service: RegistrationService,
                                  server: Server):
    """
    Register a registraytion service with the provided gRPC server.
    """
    add_RegistrationServiceServicer_to_server(service, server)



from .auth_pb2 import AccessToken, CreateRequest, CreateReply, \
    DeleteRequest, DeleteReply, GetRequest, GetReply, GetByNameRequest, \
    GetByNameReply, GetByUserRequest, GetByUserReply, RevokeRequest, \
    RevokeReply, GetByJtiRequest, GetByJtiReply, GetByWorkspaceRequest, \
    GetByWorkspaceReply, GetByOrgRequest, GetByOrgReply
